| fitted_LB | R Documentation |
Computes the fitted (predicted) matrix for a logistic biplot model on either the logit (log-odds) scale or the probability scale.
fitted_LB(object, type = c("link", "response"))
object |
An object of class |
type |
Scale of the fitted values: |
A numeric matrix of fitted values with the same dimensions as the original binary matrix.
Giovany Babativa <jgbabativam@unal.edu.co>
data("Methylation")
LB <- LogBip(Methylation, plot = FALSE)
Theta <- fitted_LB(LB, type = "link") # log-odds scale
Pi <- fitted_LB(LB, type = "response") # probability scale
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.