View source: R/performanceBLB.R
| performanceBLB | R Documentation |
Fits the binary logistic biplot model using multiple optimization algorithms and returns a summary of their computation time, convergence status, and number of function evaluations, facilitating algorithm selection.
performanceBLB(xi, k = 2, L = 0, method = NULL, maxit = NULL)
xi |
A binary matrix. |
k |
Number of dimensions. Default is |
L |
Ridge penalization parameter. Default is |
method |
Algorithm group to compare: |
maxit |
Maximum number of iterations per algorithm. |
The following algorithm groups are available via the method argument:
1 — Derivative-free methods: Nelder-Mead, UOBYQA, NEWUOA.
2 — Gradient methods (default): CG, Rcgmin.
3 — Quasi-Newton methods: BFGS, L-BFGS-B, nlm, nlminb.
4 — All of the above.
A data frame with one row per algorithm and columns:
methodAlgorithm name.
evaluatFinal value of the objective function.
convergenceConvergence status.
fevalsNumber of function evaluations.
timeElapsed computation time.
Giovany Babativa <jgbabativam@unal.edu.co>
Nash, J. C. (2011). Unifying optimization algorithms to aid software system users: optimx for R. Journal of Statistical Software, 43(9), 1–14.
Nash, J. C. (2014). On best practice optimization methods in R. Journal of Statistical Software, 60(2), 1–14.
Vicente-Villardon, J. L., & Galindo, M. P. (2006). Logistic biplots. In M. Greenacre & J. Blasius (Eds.), Multiple Correspondence Analysis and Related Methods (pp. 503–521). Chapman & Hall.
gradientDesc
data("Methylation")
set.seed(123456)
# Gradient methods (default)
performanceBLB(xi = Methylation)
performanceBLB(xi = Methylation, maxit = 150)
# Derivative-free methods
performanceBLB(xi = Methylation, method = 1)
performanceBLB(xi = Methylation, method = 1, maxit = 100)
# Quasi-Newton methods
performanceBLB(xi = Methylation, method = 3)
performanceBLB(xi = Methylation, method = 3, maxit = 100)
# All methods
performanceBLB(xi = Methylation, method = 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.