| pred_LB | R Documentation |
Predicts the binary response matrix from a fitted logistic biplot and computes the optimal classification threshold for each variable by minimising the Balanced Error Rate (BER).
pred_LB(object, x, ncuts = 100)
object |
An object of class |
x |
The original binary matrix used to fit the model. |
ncuts |
Number of equally spaced threshold candidates in |
The optimal threshold for variable j is the value \alpha_j \in [0,1]
that minimises the Balanced Error Rate:
BER_j = 1 - \frac{1}{2}
\left(\frac{TP_j}{TP_j + FN_j} + \frac{TN_j}{TN_j + FP_j}\right),
where TP, TN, FP, and FN denote true positives,
true negatives, false positives, and false negatives, respectively.
A named list of class BiplotML with components:
thresholdsData frame with the optimal threshold and minimum BER for each variable.
predictXPredicted binary matrix.
fittedConfusion matrix (sensitivity, specificity, global accuracy) for each variable.
BEROverall Balanced Error Rate (in percent).
Giovany Babativa <jgbabativam@unal.edu.co>
data("Methylation")
LB <- LogBip(Methylation, plot = FALSE)
out <- pred_LB(LB, Methylation)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.