| sdv_MM | R Documentation |
Estimates the intercept vector \mu, the row-marker matrix A,
and the column-marker matrix B using an iterative coordinate descent
Majorization-Minimization (MM) algorithm. This is the low-level function
called by LogBip when method = "MM".
sdv_MM(
x,
k = 5,
iterations = 1000,
truncated = TRUE,
random = FALSE,
epsilon = 1e-04
)
x |
A binary matrix with no missing values. |
k |
Number of dimensions. Default is |
iterations |
Maximum number of iterations. Default is |
truncated |
Logical; if |
random |
Logical; if |
epsilon |
Convergence tolerance. The algorithm stops when the relative
decrease in the loss function is below this value. Default is |
A named list with components:
muEstimated intercept vector of length p.
AEstimated row-marker matrix (n \times k).
BEstimated column-marker matrix (p \times k).
iterationsNumber of iterations performed.
loss_funcVector of normalised loss-function values at each iteration.
Giovany Babativa <jgbabativam@unal.edu.co>
Babativa-Marquez, J. G., & Vicente-Villardon, J. L. (2021). Logistic biplot by conjugate gradient algorithms and iterated SVD. Mathematics, 9(16), 2015. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3390/math9162015")}
Vicente-Villardon, J. L., & Galindo, M. P. (2006). Logistic biplots. In M. Greenacre & J. Blasius (Eds.), Multiple Correspondence Analysis and Related Methods (pp. 503–521). Chapman & Hall.
LogBip, cv_LogBip
data("Methylation")
out <- sdv_MM(x = Methylation)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.